==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fLload.h <==
// class soot.coffi.Instruction_Lload

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 1fbd3f8033e0a4d4 soot_coffi_Instruction__5fLload
// @dep_class 73e8eecee99f809f soot_coffi_Instruction__5fbytevar

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbytevar

#include "soot/coffi/Instruction__5fbytevar.h"

#ifndef _JC_soot_coffi_Instruction__5fLload_H_
#define _JC_soot_coffi_Instruction__5fLload_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fLload$sub_refs	_jc_soot_coffi_Instruction__5fLload$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fLload$sub_nonrefs	_jc_soot_coffi_Instruction__5fLload$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLload$refs	_jc_soot_coffi_Instruction__5fLload$refs;
typedef struct _jc_soot_coffi_Instruction__5fLload$nonrefs	_jc_soot_coffi_Instruction__5fLload$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLload$object	_jc_soot_coffi_Instruction__5fLload$object;

typedef const struct _jc_soot_coffi_Instruction__5fLload$vmethods	_jc_soot_coffi_Instruction__5fLload$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fLload$vtable	_jc_soot_coffi_Instruction__5fLload$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fLload$vtype	_jc_soot_coffi_Instruction__5fLload$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fLload$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fLload$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fLload$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fLload$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbytevar$vmethods	soot_coffi_Instruction__5fbytevar;
	_jc_soot_coffi_Instruction__5fLload$vmethods	soot_coffi_Instruction__5fLload;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fLload$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fLload$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLload$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLload$refs {
    _jc_soot_coffi_Instruction__5fLload$sub_refs	soot_coffi_Instruction__5fLload;
    _jc_soot_coffi_Instruction__5fbytevar$sub_refs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLload$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLload$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbytevar$sub_nonrefs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction__5fLload$sub_nonrefs	soot_coffi_Instruction__5fLload;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fLload$object {
	_jc_soot_coffi_Instruction__5fLload$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fLload$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fLload$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fLload$vtype _jc_soot_coffi_Instruction__5fLload$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fLload, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fLload$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fLload_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fLload.h <==
// class soot.coffi.Instruction_Lload

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 1fbd3f8033e0a4d4 soot_coffi_Instruction__5fLload
// @dep_class 73e8eecee99f809f soot_coffi_Instruction__5fbytevar

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbytevar

#include "soot/coffi/Instruction__5fbytevar.h"

#ifndef _JC_soot_coffi_Instruction__5fLload_H_
#define _JC_soot_coffi_Instruction__5fLload_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fLload$sub_refs	_jc_soot_coffi_Instruction__5fLload$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fLload$sub_nonrefs	_jc_soot_coffi_Instruction__5fLload$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLload$refs	_jc_soot_coffi_Instruction__5fLload$refs;
typedef struct _jc_soot_coffi_Instruction__5fLload$nonrefs	_jc_soot_coffi_Instruction__5fLload$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLload$object	_jc_soot_coffi_Instruction__5fLload$object;

typedef const struct _jc_soot_coffi_Instruction__5fLload$vmethods	_jc_soot_coffi_Instruction__5fLload$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fLload$vtable	_jc_soot_coffi_Instruction__5fLload$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fLload$vtype	_jc_soot_coffi_Instruction__5fLload$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fLload$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fLload$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fLload$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fLload$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbytevar$vmethods	soot_coffi_Instruction__5fbytevar;
	_jc_soot_coffi_Instruction__5fLload$vmethods	soot_coffi_Instruction__5fLload;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fLload$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fLload$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLload$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLload$refs {
    _jc_soot_coffi_Instruction__5fLload$sub_refs	soot_coffi_Instruction__5fLload;
    _jc_soot_coffi_Instruction__5fbytevar$sub_refs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLload$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLload$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbytevar$sub_nonrefs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction__5fLload$sub_nonrefs	soot_coffi_Instruction__5fLload;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fLload$object {
	_jc_soot_coffi_Instruction__5fLload$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fLload$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fLload$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fLload$vtype _jc_soot_coffi_Instruction__5fLload$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fLload, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fLload$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fLload_H_ */
